@@ -31,7 +31,6 @@ logger = getLogger(__name__)
 SERVICE_DESCRIPTION = 'QLDB Driver for Python v{}'.format(__version__)
 SERVICE_NAME = 'qldb-session'
 SERVICE_RETRY = {'max_attempts': 0}
-DEFAULT_CONFIG = Config(user_agent_extra=SERVICE_DESCRIPTION, retries=SERVICE_RETRY)
 DEFAULT_RETRY_CONFIG = RetryConfig()
 
 
@@ -74,7 +73,7 @@ class QldbDriver:
     :param aws_session_token: See [1].
 
     :type config: :py:class:`botocore.config.Config`
-    :param config: See [2]. Note that parameter user_agent_extra will be overwritten.
+    :param config: See [2]. Note that parameter user_agent_extra will be appended and retries will be overwritten.
 
     :type boto3_session: :py:class:`boto3.session.Session`
     :param boto3_session: The boto3 session to create the client with (see [1]). The boto3 session is expected to be
@@ -89,7 +88,7 @@ class QldbDriver:
 
     :raises TypeError: When config is not an instance of :py:class:`botocore.config.Config`.
                        When boto3_session is not an instance of :py:class:`boto3.session.Session`.
-                       When retry_config is not an instance of :py:class:pyqldb.config.retry_config.RetryConfig.
+                       When retry_config is not an instance of :py:class:`pyqldb.config.retry_config.RetryConfig`.
 
     :raises ValueError: When `max_concurrent_transactions` exceeds the limit set by the client.
                         When `max_concurrent_transactions` is negative.
@@ -116,9 +115,14 @@ class QldbDriver:
             if not isinstance(config, Config):
                 raise TypeError('config must be of type botocore.config.Config. Found: {}'
                                 .format(type(config).__name__))
-            self._config = config.merge(DEFAULT_CONFIG)
+            self._config = config
+            self._config.retries = SERVICE_RETRY
+            if self._config.user_agent_extra:
+                self._config.user_agent_extra = ' '.join([SERVICE_DESCRIPTION, self._config.user_agent_extra])
+            else:
+                self._config.user_agent_extra = SERVICE_DESCRIPTION
         else:
-            self._config = DEFAULT_CONFIG
+            self._config = Config(user_agent_extra=SERVICE_DESCRIPTION, retries=SERVICE_RETRY)
 
         if retry_config is not None:
             if not isinstance(retry_config, RetryConfig):
@@ -186,7 +190,7 @@ class QldbDriver:
         Get the list of table names in the ledger.
 
         :rtype: :py:class:`pyqldb.cursor.buffered_cursor.BufferedCursor`
-        :return: Iterable of table names in :py:class:`amazon.ion.simple_types.IonPyText`.
+        :return: Iterable of table names in :py:class:`amazon.ion.simple_types.IonPyText` format found in the ledger.
 
         :raises DriverClosedError: When this driver is closed.
         """
@@ -202,9 +206,12 @@ class QldbDriver:
         This is the primary method to execute a transaction against Amazon QLDB ledger.
 
         :type query_lambda: function
-        :param query_lambda: The lambda function to execute. A lambda function cannot have any side effects as
-                             it may be invoked multiple times, and the result cannot be trusted until the transaction is
-                             committed.
+        :param query_lambda: The lambda function to execute. The function receives an instance of
+                             :py:class:`pyqldb.execution.executor.Executor` which can be used to execute statements.
+                             The instance of :py:class:`pyqldb.execution.executor.Executor` wraps an implicitly created
+                             transaction. The transaction will be implicitly committed when the passed function returns.
+                             The lambda function cannot have any side effects as it may be invoked multiple
+                             times, and the result cannot be trusted until the transaction is committed.
 
         :type retry_config: :py:class:`pyqldb.config.retry_config.RetryConfig`
         :param retry_config: Config to specify max number of retries, base and custom backoff strategy for retries.
