@@ -9,6 +9,8 @@
 # CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 # and limitations under the License.
 
+import re
+
 
 class IllegalStateError(Exception):
     pass
@@ -46,6 +48,12 @@ class SessionPoolEmptyError(Exception):
                          'before retrying.'.format(str(timeout)))
 
 
+class StartTransactionError(Exception):
+    def __init__(self, error):
+        super().__init__('Failed to start transaction')
+        self.error = error
+
+
 def is_occ_conflict_exception(e):
     """
     Is the exception an OccConflictException?
@@ -60,6 +68,20 @@ def is_occ_conflict_exception(e):
     return is_occ
 
 
+def is_bad_request_exception(e):
+    """
+    Is the exception a BadRequestException?
+
+    :type e: :py:class:`botocore.exceptions.ClientError`
+    :param e: The ClientError caught.
+
+    :rtype: bool
+    :return: True if the exception is an BadRequestException. False otherwise.
+    """
+    is_bad_request = e.response['Error']['Code'] == "BadRequestException"
+    return is_bad_request
+
+
 def is_invalid_session_exception(e):
     """
     Is the exception an InvalidSessionException?
@@ -74,6 +96,24 @@ def is_invalid_session_exception(e):
     return is_invalid_session
 
 
+def is_transaction_expired_exception(e):
+    """
+    Does this exception denote that a transaction has expired?
+
+    :type e: :py:class:`botocore.exceptions.ClientError`
+    :param e: The ClientError caught.
+
+    :rtype: bool
+    :return: True if the exception denote that a transaction has expired. False otherwise.
+    """
+    is_invalid_session = e.response['Error']['Code'] == 'InvalidSessionException'
+
+    if "Message" in e.response["Error"]:
+        return is_invalid_session and re.search("Transaction .* has expired", e.response["Error"]["Message"])
+
+    return False
+
+
 def is_retriable_exception(e):
     """
     Is the exception a retriable exception?
